# Simple Group Analysis
Decomposes a set of expressions into a group expression.
The toolkit currently offers enrichment analysis, hierarchical
enrichment analysis, PLS regression, Shape alignment or clustering
as well as  rudimentary factor analysis.
The expression regulation can be studied via a statistical
test that relates it to the observables in the journal file.
The final p values are then FDR corrected and the resulting
adjusted p values are produced.


Visit the active code via :
https://github.com/richardtjornhammar/impetuous

Visit the published code : 
https://doi.org/10.5281/zenodo.2594690

Cite using :
DOI: 10.5281/zenodo.2594690

Install with :
pip install impetuous-gfa
